"""In-process tests for the modulemd generator"""

import pytest
from click.testing import CliRunner

import modulemd
from _fedmod.cli import _cli_commands
from _fedmod.module_generator import ModuleGenerator

def _generate_modulemd(rpms):
    cmd = ['rpm2module']
    cmd.extend(rpms)
    runner = CliRunner()
    result = runner.invoke(_cli_commands, cmd)
    assert result.exit_code == 0
    modmd = modulemd.ModuleMetadata()
    modmd.loads(result.output)
    return modmd


class TestSinglePackageInput(object):

    def test_generated_modulemd_file(self):
        input_rpms = ('grep',)
        modmd = _generate_modulemd(input_rpms)

        # Expected description for 'grep'
        assert modmd.summary == "Generated module for grep"
        assert modmd.description == "Module auto-generated by fedmod"

        # Expected licenses for 'grep'
        assert modmd.module_licenses == {'MIT'}
        assert modmd.content_licenses == set()

        # Only given modules are listed in the public API
        assert sorted(modmd.api.rpms) == sorted(input_rpms)

        # Expected components for grep
        assert set(modmd.components.rpms) == set(input_rpms)

        # Expected module dependencies for grep
        assert set(modmd.buildrequires) == {'platform',}
        assert set(modmd.requires) == {'platform',}


class TestMultiplePackageInput(object):

    def test_generated_modulemd_file(self):
        input_rpms = ('grep', 'haproxy')
        modmd = _generate_modulemd(input_rpms)

        # Can't generate descriptive metadata when given multiple RPMs
        assert modmd.summary == "Generated module for ('grep', 'haproxy')"
        assert modmd.description == "Module auto-generated by fedmod"

        # Expected licenses for grep + haproxy
        assert modmd.module_licenses == {'MIT'}
        assert len(modmd.content_licenses) == 0 # This doesn't seem right...

        # Only given modules are listed in the public API
        assert sorted(modmd.api.rpms) == sorted(input_rpms)

        # Expected components for grep + haproxy
        expected_components = set(input_rpms)
        assert set(modmd.components.rpms) == expected_components

        # Expected module dependencies for grep + haproxy
        assert set(modmd.buildrequires) == {'platform',}
        assert set(modmd.requires) == {'platform',}


